<?php

namespace Ems\Controllers;

use Exception\Messages;
use Service\LogService;
use Service\OAuth\OAuthCustomImpl;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\HTTP\Kernel;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;


use Ems\Services\ParceiroNegocioService;

class ParceiroNegocioController {
    protected $parceiroNegocioService;

    public function __construct(ParceiroNegocioService $parceiroNegocioService) {
        $this->parceiroNegocioService = $parceiroNegocioService;
    }

    public function getComunicacaoParc(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrVinculo = $row['NRVINCULOM'];
            $nrorg = $row['NRORG'];

            $comunicacao = $this->parceiroNegocioService->getComunicacaoParc($nrorg, $nrVinculo);

            $response->addDataSet(new DataSet('getComunicacaoParc', $comunicacao));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getContaCorrenteParc(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrVinculo = $row['NRVINCULOM'];
            $nrorg = $row['NRORG'];

            $comunicacao = $this->parceiroNegocioService->getContaCorrenteParc($nrorg, $nrVinculo);

            $response->addDataSet(new DataSet('getContaCorrenteParc', $comunicacao));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getEnderecoParc(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrVinculo = $row['NRVINCULOM'];
            $nrorg = $row['NRORG'];

            $endereco = $this->parceiroNegocioService->getEnderecoParc($nrorg, $nrVinculo);

            $response->addDataSet(new DataSet('getEnderecoParc', $endereco));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

}
